﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace cvicenie_04_aktivitka.Store
{
    public class Store<T> where T : IProductable
    {
        public Dictionary<T, int> Items { get; set; }

        public double ShopPrice() => Items.Sum(item => item.Key.Price * item.Value);
    }

    public static class StoreExtensions
    {
        public static void AddItemToCart<T>(this Store<T> t, T item) where T : IProductable
        {
            if (!t.Items.TryGetValue(item, out var _))
                throw new ArgumentException("Not in stock");

            t.Items[item] -= 1;

            if (t.Items[item] == 0)
                t.Items.Remove(item);
        }

        public static void PrintInfoAboutStore<T>(this Store<T> t) where T : IProductable
        {
            foreach (var (k, v) in t.Items)
                Console.WriteLine($"Item {k.ItemName}: {k.Price}$, {v}ks on de sklad");

            Console.WriteLine($"Total price for the store: {t.ShopPrice()}");
        }

        public static void ReturnItemToShop<T>(this Store<T> t, T item) where T : IProductable
        {
            if (!t.Items.TryGetValue(item, out var count))
                count = 0;

            t.Items[item] = count + 1;
        }
    }
}
